@@ -79,6 +79,8 @@ class EmissionFitting:
     _SLOPE_FIX_PAR = dict(value=None, min=-np.inf, max=np.inf, vary=False, expr=None)
     _INTER_FIX_PAR = dict(value=None, min=-np.inf, max=np.inf, vary=False, expr=None)
 
+    _minimize_method = 'leastsq'
+
     # Switch for emission and absorption lines
 
     def __init__(self):
@@ -222,18 +224,6 @@ class EmissionFitting:
 
     def gauss_lmfit(self, line_label, x, y, weights, user_conf={}, lines_df=None, z_obj=0):
 
-        """
-        :param line_label:
-        :param x:
-        :param y:
-        :param weights:
-        :param user_conf: Input dictionary with specific fit configuration {name , value, vary, min, max, expr,
-        brute_step}. The model parameters ['slope', 'intercept', 'amp', 'center', 'sigma', 'fwhm', 'height'].
-        The configuration of each parameter (NAME VALUE VARY MIN  MAX  EXPR  BRUTE_STEP)
-        :param lines_df:
-        :return:
-        """
-
         # Check if line is in a blended group
         line_ref = self.blended_label if self.blended_check else line_label
 
@@ -276,10 +266,10 @@ class EmissionFitting:
 
         # Fit the line
         self.fit_params = fit_model.make_params()
-        self.fit_output = fit_model.fit(y, self.fit_params, x=x, weights=weights)
+        self.fit_output = fit_model.fit(y, self.fit_params, x=x, weights=weights, method=self._minimize_method)
 
         if not self.fit_output.errorbars:
-            print(f'-- WARNING: Line measuring error at {line_label}')
+            print(f'-- WARNING: Parameter(s) uncertainty could not be measured for line {line_label}')
 
         # Generate containers for the results
         eqw_g, eqwErr_g = np.empty(n_comps), np.empty(n_comps)
