@@ -46,7 +46,7 @@ def label_decomposition(input_lines, recomb_atom=('H1', 'He1', 'He2'), blended_d
     :param user_format: Dictionary with the user notation for the latex labels. This overwrites the default notation.
     :type user_format: dict, optional
 
-    :return: 3 arrays (or scalars) with the input line(s) transition wavelength, ion and scientific notation in latex
+    :return: 3 arrays (or scalars) with the input line(s) transition ion, wavelength and scientific notation in latex format.
     :rtype: numpy.ndarray
 
     :Example:
