@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 from pathlib import Path
-from lmfit import fit_report
+from lmfit import fit_report as lmfit_fit_report
 from sys import exit
 from astropy.table import Table
 from astropy.io import fits
@@ -19,23 +19,40 @@ from matplotlib.widgets import SpanSelector
 
 class Spectrum(EmissionFitting, LiMePlots, LineFinder):
 
+    """
+    This class provides a set of tools to measure lines from the spectra of ionized gas. The user provides a spectrum
+    with input arrays for the observation wavelength and flux.
+
+    Optionally, the user can provide the sigma spectrum with the pixel uncertainty. This array must be in the same
+    units as the ``input_flux``.
+
+    It is recommended to provide the object redshift and a flux normalization. This guarantees the functionality of
+    the class functions.
+
+    Finally, the user can also provide a two value array with the same wavelength limits. This array must be in the
+    same units and frame of reference as the ``.input_wave``.
+
+    :param input_wave: wavelength array
+    :type input_wave: numpy.array
+
+    :param input_flux: flux array
+    :type input_flux: numpy.array
+
+    :param input_err: sigma array of the ``input_flux``
+    :type input_err: numpy.array, optional
+
+    :param redshift: spectrum redshift
+    :type redshift: float, optional
+
+    :param norm_flux: spectrum flux normalization
+    :type norm_flux: float, optional
+
+    :param crop_waves: wavelength array crop values
+    :type norm_flux: float, optional
+    """
+
     def __init__(self, input_wave=None, input_flux=None, input_err=None, redshift=0, norm_flux=1.0, crop_waves=None):
 
-        """
-
-        This class provides a set of tools to measure emission lines from ionized gas to study its chemistry and kinematics
-        The user provides an spectrum object in the observed frame alongside the object redshift and normalization flux
-
-        :param input_wave: Wavelength array
-        :param input_flux: Flux array
-        :param input_err: Standard deviation array
-        :param redshift: Object redshift
-        :param norm_flux: Flux normalization
-        :param crop_waves: Wavelength limits for the analysis
-
-
-        """
-
         # Load parent classes
         LineFinder.__init__(self)
         EmissionFitting.__init__(self)
@@ -78,28 +95,61 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
 
         return
 
-    def fit_from_wavelengths(self, label, line_wavelengths, user_cfg={}, algorithm='lmfit', emission=True,
-                             adjacent_cont=True):
+    def fit_from_wavelengths(self, line, mask, user_cfg={}, fit_method='leastsq', emission=True, adjacent_cont=True):
 
         """
-        This function fits an emission line by providing its label, location and an optional fit configuration. The
-        algorithm accounts for the object redshift if it was provided by the user and corrects the input
-        line_wavelengths
 
-        :param emission_check:
-        :param str label: Line reference incluiding the ion and wavelength. Example: O3_5007A
-        :param np.ndarray line_wavelengths: Array with 6 wavelength values defining an emision line left continuum,  emission region and right continuum
-        :param dict user_cfg: Dictionary with the user configuration for the fitting
-        :param algorithm: Algorithm for the line profile fitting (Not implemented)
+        This function fits a line given its line and spectral mask. The line notation consists in the transition
+        ion and wavelength (with units) separated by an underscore, i.e. O3_5007A.
+
+        The location mask consists in a 6 values array with the wavelength boundaries for the line location and two
+        adjacent continua. These wavelengths must be sorted by increasing order and in the rest frame.
+
+        The user can specify the properties of the fitting: Number of components and parameter boundaries. Please check
+        the documentation for the complete details.
+
+        The user can specify the minimization algorithm for the `LmFit library <https://lmfit.github.io/lmfit-py/fitting.html#lmfit.minimizer.Minimizer.minimize>`_.
+
+        By default, the algorithm assumes an emission line. The user can set the parameter ``emission=False`` for an
+        absorption.
+
+        If the sigma spectrum was not provided, the fitting estimates the pixel uncertainty from the adjacent continua flux
+        standard deviation assuming a linear profile. If the parameter ``adjacent_cont=True`` the adjacent continua is also
+        use to calculate the continuum at the line location. Otherwise, only the line continuum is calculated only with the
+        first and last pixel in the line band (the 3rd and 4th values in the ``line_wavelengths`` array)
+
+        :param line: line line in the ``LiMe`` notation, i.e. H1_6563A_b
+        :type line: string
+
+        :param mask: 6 wavelengths spectral mask with the blue continuum, line and red continuum bands.
+        :type mask: numpy.ndarray
+
+        :param user_cfg: Dictionary with the fitting configuration.
+        :type user_cfg: dict, optional
+
+        :param algorithm: Minimizing algorithm for the LmFit library. The default method is ``leastsq``.
+        :type algorithm: str, optional
+
+        :param emission: Boolean check for the line type. The default is ``True`` for an emission line
+        :type emission: bool, optional
+
+        :param adjacent_cont: Boolean check for the line continuum calculation. The default value ``True`` includes the
+                              adjacent continua array
+        :type adjacent_cont: bool, optional
+
         """
 
         # For security previous measurement is cleared and a copy of the user configuration is used
         self.clear_fit()
         fit_conf = user_cfg.copy()
 
+        # Estate the minimizing method for the fitting (this parameter is not restored to default by the self.clear_fit function)
+        self._minimize_method = fit_method
+
+
         # Label the current measurement
-        self.line = label
-        self.lineWaves = line_wavelengths
+        self.line = line
+        self.lineWaves = mask
 
         # Global fit parameters
         self._emission_check = emission
@@ -144,6 +194,112 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
 
         return
 
+    def display_results(self, line=None, fit_report=False, plot=True, log_scale=True, frame='obs',
+                        output_address=None):
+
+        """
+
+        This function plots or prints the fitting of a line. If no line specified, the values used are those from the
+        last fitting.
+
+        The ``fit_report=True`` includes the `the LmFit log <https://lmfit.github.io/lmfit-py/fitting.html#getting-and-printing-fit-reports>`_.
+
+        If an ``output_address`` is provided, the outputs will be saved to a file instead of displayed on the terminal/window.
+        The text file will have the address output file extension changed to .txt, while the plot will use the one provided
+        by the user.
+
+        :param line: line fitting to query. If none is provided, the one from the last fitting is considered
+        :type line: str, optional
+
+        :param fit_report: Summary of the fitting inputs and outputs. The default value is ``False``
+        :type fit_report: bool, optional
+
+        :param plot: Plot of the fitting inputs and outputs. The default value is ``True``
+        :type plot: bool, optional
+
+        :param log_scale: Check for the scale of the flux (vertical) axis in the plot. The default value is ``True``
+        :type log_scale: bool, optional
+
+        :param frame: Frame of reference for the plot. The default value is the observation frame ``frame='obs'``
+        :type frame: str, optional
+
+        :param output_address: Output address for the measurement report and/or plot. If provided the results will be stored
+                               instead of displayed on screen.
+        :type output_address: str, optional
+
+        """
+
+        # Check if the user provided an output file address
+        if output_address is not None:
+            output_path = Path(output_address)
+
+        # Fitting report
+        if fit_report:
+
+            if line is None:
+                if self.line is not None:
+                    line = self.line
+                    output_ref = (f'\nLine line: {line}\n'
+                                  f'- Line mask: {self.lineWaves}\n'
+                                  f'- Normalization flux: {self.norm_flux}\n'
+                                  f'- Redshift: {self.redshift}\n'
+                                  f'- Peak wavelength: {self.peak_wave:.2f}; peak intensity: {self.peak_flux:.2f}\n'
+                                  f'- Cont. slope: {self.m_cont:.2e}; Cont. intercept: {self.n_cont:.2e}\n')
+
+                    if self.blended_check:
+                        mixtureComponents = np.array(self.blended_label.split('-'))
+                    else:
+                        mixtureComponents = np.array([line], ndmin=1)
+
+                    output_ref += f'\n- {line} Intg flux: {self.intg_flux:.3f} +/- {self.intg_err:.3f}\n'
+
+                    if mixtureComponents.size == 1:
+                        output_ref += f'- {line} Eqw (intg): {self.eqw[0]:.2f} +/- {self.eqw_err[0]:.2f}\n'
+
+                    for i, lineRef in enumerate(mixtureComponents):
+                        output_ref += (f'\n- {lineRef} gaussian fitting:\n'
+                                       f'-- Gauss flux: {self.gauss_flux[i]:.3f} +/- {self.gauss_err[i]:.3f}\n'
+                                       # f'-- Amplitude: {self.amp[i]:.3f} +/- {self.amp_err[i]:.3f}\n'
+                                       f'-- Center: {self.center[i]:.2f} +/- {self.center_err[i]:.2f}\n'
+                                       f'-- Sigma (km/s): {self.sigma_vel[i]:.2f} +/- {self.sigma_vel_err[i]:.2f}\n')
+                else:
+                    output_ref = f'- No measurement performed\n'
+
+            # Case with line input: search and show that measurement
+            elif self.log is not None:
+                if line in self.log.index:
+                    output_ref = self.log.loc[line].to_string
+                else:
+                    output_ref = f'- WARNING: {line} not found in  lines table\n'
+            else:
+                output_ref = '- WARNING: Measurement lines log not defined\n'
+
+            # Display the print lmfit report if available
+            if fit_report:
+                if self.fit_output is not None:
+                    output_ref += f'\n- LmFit output:\n{lmfit_fit_report(self.fit_output)}\n'
+                else:
+                    output_ref += f'\n- LmFit output not available\n'
+
+            # Display the report
+            if output_address is None:
+                print(output_ref)
+            else:
+                output_txt = f'{output_path.parent/output_path.stem}.txt'
+                with open(output_txt, 'w+') as fh:
+                    fh.write(output_ref)
+
+        # Fitting plot
+        if plot:
+
+            if output_address is None:
+                self.plot_fit_components(self.fit_output, log_scale=log_scale, frame=frame)
+
+            else:
+                self.plot_fit_components(self.fit_output, log_scale=log_scale, frame=frame, output_address=output_address)
+
+        return
+
     def import_line_kinematics(self, user_conf, z_cor):
 
         # Check if imported kinematics come from blended component
@@ -199,7 +355,7 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
 
     def results_to_database(self, lineLabel, linesDF, fit_conf, export_params=_LOG_EXPORT):
 
-        # Recover label data
+        # Recover line data
         if self.blended_check:
             line_components = self.blended_label.split('-')
         else:
@@ -235,70 +391,6 @@ class Spectrum(EmissionFitting, LiMePlots, LineFinder):
 
         return
 
-    def display_results(self, label=None, show_fit_report=False, show_plot=False, log_scale=True, frame='obs',
-                        save_address=None):
-
-        # Case no line as input: Show the current measurement
-        # Show the result
-        if show_fit_report:
-
-            if label is None:
-                if self.line is not None:
-                    label = self.line
-                    output_ref = (f'\nLine label: {label}\n'
-                                  f'- Line mask: {self.lineWaves}\n'
-                                  f'- Normalization flux: {self.norm_flux}\n'
-                                  f'- Redshift: {self.redshift}\n'
-                                  f'- Peak wavelength: {self.peak_wave:.2f}; peak intensity: {self.peak_flux:.2f}\n'
-                                  f'- Cont. slope: {self.m_cont:.2e}; Cont. intercept: {self.n_cont:.2e}\n')
-
-                    if self.blended_check:
-                        mixtureComponents = np.array(self.blended_label.split('-'))
-                    else:
-                        mixtureComponents = np.array([label], ndmin=1)
-
-                    output_ref += f'\n- {label} Intg flux: {self.intg_flux:.3f} +/- {self.intg_err:.3f}\n'
-
-                    if mixtureComponents.size == 1:
-                        output_ref += f'- {label} Eqw (intg): {self.eqw[0]:.2f} +/- {self.eqw_err[0]:.2f}\n'
-
-                    for i, lineRef in enumerate(mixtureComponents):
-                        output_ref += (f'\n- {lineRef} gaussian fitting:\n'
-                                       f'-- Gauss flux: {self.gauss_flux[i]:.3f} +/- {self.gauss_err[i]:.3f}\n'
-                                       # f'-- Amplitude: {self.amp[i]:.3f} +/- {self.amp_err[i]:.3f}\n'
-                                       f'-- Center: {self.center[i]:.2f} +/- {self.center_err[i]:.2f}\n'
-                                       f'-- Sigma (km/s): {self.sigma_vel[i]:.2f} +/- {self.sigma_vel_err[i]:.2f}\n')
-                else:
-                    output_ref = f'- No measurement performed\n'
-
-            # Case with line input: search and show that measurement
-            elif self.log is not None:
-                if label in self.log.index:
-                    output_ref = self.log.loc[label].to_string
-                else:
-                    output_ref = f'- WARNING: {label} not found in  lines table\n'
-            else:
-                output_ref = '- WARNING: Measurement lines log not defined\n'
-
-            # Display the print lmfit report if available
-            if show_fit_report:
-                if self.fit_output is not None:
-                    output_ref += f'\n- LmFit output:\n{fit_report(self.fit_output)}\n'
-                else:
-                    output_ref += f'\n- LmFit output not available\n'
-
-            print(output_ref)
-
-        # Display plot
-        if show_plot:
-            self.plot_fit_components(self.fit_output, log_scale=log_scale, frame=frame)
-
-        # Save the plot figure Dania feature
-        if save_address is not None:
-            self.plot_fit_components(self.fit_output, log_scale=log_scale, frame=frame, output_address=save_address)
-
-        return
-
     def clear_fit(self):
         super().__init__()
         return
@@ -563,8 +655,8 @@ class MaskInspector(Spectrum):
         self.in_fig = event.canvas.figure
         self.in_ax = event.inaxes
 
-        # TODO we need a better way to index than the latex label
-        # Recognise line label
+        # TODO we need a better way to index than the latex line
+        # Recognise line line
         idx_line = self.log.index == self.in_ax.get_title()
         self.lineLabel = self.log.loc[idx_line].index.values[0]
         self.lineWaves = self.log.loc[idx_line, 'w1':'w6'].values[0]
